﻿;----------------------------------------------------------------------------------------------------
; AutoHotKey script to create a copy of a video file with optional resizing, soundtrack and overlay
;----------------------------------------------------------------------------------------------------
; Usage:
; 1) Copy this script and ffmpeg.exe to a suitable folder e.g. C:\video_script\video.ahk
; 2) Exit DSLR Remote Pro and run the Configure utility
; 3) Open the StatusCmd section in the Configure utility and set PhotoboothStatusCmdEnable to enable
;    and set PhotoboothStatusCmdXML to the path of this script e.g. C:\video_script\video.ahk
; 4) Copy the soundtrack MP3 file and overlay PNG file to the script folder
; 5) Edit the 'music', 'overlay', 'rescaleH' and 'outputSubDir' lines below
;
; To disable the script:
; 1) Exit DSLR Remote Pro and run the Configure utility
; 2) Open the StatusCmd section in the Configure utility and uncheck PhotoboothStatusCmdEnable
;
; FFmpeg can be downloaded from https://www.ffmpeg.org/
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script comes with no warranty or support whatsoever and may be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
; 20180711: fixed problems with video pathnames containing spaces
;----------------------------------------------------------------------------------------------------
#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
; #Warn  ; Enable warnings to assist with detecting common errors.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

; optional soundtrack to add, omit if no sound required
music = music.mp3

; optional overlay, omit if not required
overlay = overlay.png

; optional resizing, height must be a multiple of 2, set to 0 if resizing not required
rescaleH = 360

; subfolder in which to save the output video
outputSubDir = video

IfExist %1%
{
	; Extract filename and directory from XML pathname
	dir = %1%
	RegExMatch(dir, "([^\\]+)$", filename) 
	RegExMatch(dir, "(.*)\\", dir) 

	; read video filename from XML
	FileRead, Contents, %1%
	RegExMatch(Contents, "<video_file>(.*)</video_file>", video) 

	IfExist %dir%\%video1%
	{
		cmd = ffmpeg.exe -i "%dir%\%video1%"
		filter :=
		IfExist %overlay%
		{
			; add overlay
			cmd = %cmd% -i "%overlay%"
			if rescaleH > 0
			{
				; resize video (stream 0) then add overlay (stream 1)
				filter = -filter_complex "[0:v]scale=-1:%rescaleH%[bg],[bg][1:v]overlay=0:0"
			}
			else
			{
				; original video (stream 0) with overlay (stream 1)
				filter = -filter_complex "[0:v][1:v]overlay=0:0"
			}
		}
		else if rescaleH > 0
		{
			; resize video using video filter
			filter = -vf scale=-1:%rescaleH%
		}
		IfExist %music%
		{
			; add music and truncate video to shortest clip
			cmd = %cmd% -i "%music%"
			filter = %filter% -c:a copy -shortest
		}

		outputDir = %dir%\%outputSubDir%
		FileCreateDir %outputDir%
		cmd = %cmd% %filter% "%outputDir%\%video1%"
		;MsgBox %cmd%
		run,%cmd%,,Hide
	}
}
